==> texinfo_7.1.orig.tar.xz: texinfo-7.1/tp/t/results/coverage/center.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'center'} = {
  'contents' => [
    {
      'contents' => [
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'args' => [
            {
              'contents' => [
                {
                  'text' => 'in center '
                },
                {
                  'args' => [
                    {
                      'contents' => [
                        {
                          'text' => 'in code'
                        }
                      ],
                      'type' => 'brace_command_arg'
                    }
                  ],
                  'cmdname' => 'code',
                  'source_info' => {
                    'file_name' => '',
                    'line_nr' => 2,
                    'macro' => ''
                  }
                }
              ],
              'info' => {
                'spaces_after_argument' => {
                  'text' => '
'
                }
              },
              'type' => 'line_arg'
            }
          ],
          'cmdname' => 'center',
          'info' => {
            'spaces_before_argument' => {
              'text' => '  '
            }
          },
          'source_info' => {
            'file_name' => '',
            'line_nr' => 2,
            'macro' => ''
          }
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'type' => 'before_node_section'
    }
  ],
  'type' => 'document_root'
};

$result_texis{'center'} = '
@center  in center @code{in code}

';


$result_texts{'center'} = '
in center in code

';

$result_errors{'center'} = [];


$result_floats{'center'} = {};



$result_converted{'plaintext'}->{'center'} = '                          in center ‘in code’

';


$result_converted{'html_text'}->{'center'} = '
<div class="center">in center <code class="code">in code</code>
</div>
';


$result_converted{'xml'}->{'center'} = '
<center spaces="  ">in center <code>in code</code></center>

';


$result_converted{'latex_text'}->{'center'} = '
\\begin{center}
in center \\texttt{in code}
\\end{center}

';


$result_converted{'docbook'}->{'center'} = '
<simpara role="center">in center <literal>in code</literal></simpara>

';

1;

==> texinfo_7.2.orig.tar.xz: texinfo-7.2/tp/t/results/coverage/center.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'center'} = {
  'contents' => [
    {
      'contents' => [
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'args' => [
            {
              'contents' => [
                {
                  'text' => 'in center '
                },
                {
                  'args' => [
                    {
                      'contents' => [
                        {
                          'text' => 'in code'
                        }
                      ],
                      'type' => 'brace_container'
                    }
                  ],
                  'cmdname' => 'code',
                  'source_info' => {
                    'line_nr' => 2
                  }
                }
              ],
              'info' => {
                'spaces_after_argument' => {
                  'text' => '
'
                }
              },
              'type' => 'line_arg'
            }
          ],
          'cmdname' => 'center',
          'info' => {
            'spaces_before_argument' => {
              'text' => '  '
            }
          },
          'source_info' => {
            'line_nr' => 2
          }
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        }
      ],
      'type' => 'before_node_section'
    }
  ],
  'type' => 'document_root'
};

$result_texis{'center'} = '
@center  in center @code{in code}

';


$result_texts{'center'} = '
in center in code

';

$result_errors{'center'} = [];


$result_floats{'center'} = {};



$result_converted{'plaintext'}->{'center'} = '                          in center ‘in code’

';


$result_converted{'html_text'}->{'center'} = '
<div class="center">in center <code class="code">in code</code>
</div>
';


$result_converted{'xml'}->{'center'} = '
<center spaces="  ">in center <code>in code</code></center>

';


$result_converted{'latex_text'}->{'center'} = '
\\begin{center}
in center \\texttt{in code}
\\end{center}

';


$result_converted{'docbook'}->{'center'} = '
<simpara role="center">in center <literal>in code</literal></simpara>

';

1;
